Index: ash/common/shelf/overflow_button.h |
diff --git a/ash/common/shelf/overflow_button.h b/ash/common/shelf/overflow_button.h |
index 0e1617a4cc80374431a976f632deefc84e2e3ef4..503811de782446b416be8036a0647755f0b7440c 100644 |
--- a/ash/common/shelf/overflow_button.h |
+++ b/ash/common/shelf/overflow_button.h |
@@ -24,8 +24,8 @@ class OverflowButton : public views::CustomButton { |
void OnOverflowBubbleShown(); |
void OnOverflowBubbleHidden(); |
- // Sets alpha value of the background and schedules a paint. |
- void SetBackgroundAlpha(int alpha); |
+ // Updates background and schedules a paint. |
+ void UpdateShelfItemBackground(SkColor color); |
private: |
// views::CustomButton: |
@@ -66,8 +66,8 @@ class OverflowButton : public views::CustomButton { |
ShelfView* shelf_view_; |
WmShelf* wm_shelf_; |
- // Alpha value used to paint the background. |
- int background_alpha_; |
+ // Color used to paint the background. |
+ SkColor background_color_; |
DISALLOW_COPY_AND_ASSIGN(OverflowButton); |
}; |